from django.contrib.admin import AdminSite, site

from ..config import get_config


class BatonAdminSite(AdminSite):
    site_header = get_config('SITE_HEADER')
    site_title = get_config('SITE_TITLE')
    index_title = get_config('INDEX_TITLE')
    index_template = 'baton/index.html' if get_config(
        'ANALYTICS') else 'admin/index.html'

    def __init__(self, *args, **kwargs):
        """ Registers all apps with BatonAdminSite """
        super(BatonAdminSite, self).__init__(*args, **kwargs)
        # copy registered actions
        self._actions = site._actions
        self._registry.update(site._registry)
        for model in site._registry:
            self.unregister([model])
            self.register([model], type(site._registry[model]))


site = BatonAdminSite()  # noqa



# -*- coding: utf-8 -*-
from django.conf import settings
from django.utils.html import mark_safe
from django.utils.translation import ugettext as _

default_config = {
    'SITE_TITLE': 'Baton',
    'SITE_HEADER': '<img src="%sbaton/img/logo.png" />' % settings.STATIC_URL,
    'INDEX_TITLE': _('Site administration'),
    'MENU_TITLE': _('Menu'),
    'SUPPORT_HREF': 'https://github.com/otto-torino/django-baton/issues',
    'COPYRIGHT': 'copyright © 2017 <a href="https://www.otto.to.it">Otto srl</a>', # noqa
    'POWERED_BY': '<a href="https://www.otto.to.it">Otto srl</a>',
    'CONFIRM_UNSAVED_CHANGES': True,
    'SHOW_MULTIPART_UPLOADING': True,
    'ENABLE_IMAGES_PREVIEW': True,
    'CHANGELIST_FILTERS_IN_MODAL': False,
    'MENU_ALWAYS_COLLAPSED': False,
    'GRAVATAR_DEFAULT_IMG': 'retro',
}


def get_config(key):
    safe = ['SITE_HEADER', 'COPYRIGHT', 'POWERED_BY', ]
    user_settings = getattr(settings, 'BATON', None)

    if user_settings is None:
        value = default_config.get(key, None)
    else:
        value = user_settings.get(key, default_config.get(key, None))

    if key in safe:
        return mark_safe(value)

    return value



from django.conf.urls import url

from .views import GetAppListJsonView, GetGravatartUrlJsonView


urlpatterns = [
    url(r'^app-list-json/$', GetAppListJsonView.as_view(),
        name='baton-app-list-json'),
    url(r'^gravatar/$', GetGravatartUrlJsonView.as_view(),
        name='baton-gravatar-json'),
]
